==> aliyun-python-sdk-vod-2.15.12.tar.gz: aliyun-python-sdk-vod-2.15.12/aliyunsdkvod/request/v20170321/DeleteTranscodeTemplateGroupRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvod.endpoint import endpoint_data

class DeleteTranscodeTemplateGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteTranscodeTemplateGroup','vod')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_TranscodeTemplateIds(self):
		return self.get_query_params().get('TranscodeTemplateIds')

	def set_TranscodeTemplateIds(self,TranscodeTemplateIds):
		self.add_query_param('TranscodeTemplateIds',TranscodeTemplateIds)

	def get_ForceDelGroup(self):
		return self.get_query_params().get('ForceDelGroup')

	def set_ForceDelGroup(self,ForceDelGroup):
		self.add_query_param('ForceDelGroup',ForceDelGroup)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_TranscodeTemplateGroupId(self):
		return self.get_query_params().get('TranscodeTemplateGroupId')

	def set_TranscodeTemplateGroupId(self,TranscodeTemplateGroupId):
		self.add_query_param('TranscodeTemplateGroupId',TranscodeTemplateGroupId)

==> aliyun-python-sdk-vod-2.16.2.tar.gz: aliyun-python-sdk-vod-2.16.2/aliyunsdkvod/request/v20170321/DeleteTranscodeTemplateGroupRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvod.endpoint import endpoint_data

class DeleteTranscodeTemplateGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'vod', '2017-03-21', 'DeleteTranscodeTemplateGroup')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_TranscodeTemplateIds(self):
		return self.get_query_params().get('TranscodeTemplateIds')

	def set_TranscodeTemplateIds(self,TranscodeTemplateIds):
		self.add_query_param('TranscodeTemplateIds',TranscodeTemplateIds)

	def get_TranscodeTemplateGroupId(self):
		return self.get_query_params().get('TranscodeTemplateGroupId')

	def set_TranscodeTemplateGroupId(self,TranscodeTemplateGroupId):
		self.add_query_param('TranscodeTemplateGroupId',TranscodeTemplateGroupId)

	def get_ForceDelGroup(self):
		return self.get_query_params().get('ForceDelGroup')

	def set_ForceDelGroup(self,ForceDelGroup):
		self.add_query_param('ForceDelGroup',ForceDelGroup)
